@@ -5,7 +5,7 @@ import shutil
 import subprocess
 import sys
 from tempfile import NamedTemporaryFile
-from typing import List, Union
+from typing import List, Optional, Union
 
 from tufup.utils import remove_path
 
@@ -21,7 +21,7 @@ def install_update(
         src_dir: Union[pathlib.Path, str],
         dst_dir: Union[pathlib.Path, str],
         purge_dst_dir: bool = False,
-        exclude_from_purge: List[Union[pathlib.Path, str]] = None,
+        exclude_from_purge: Optional[List[Union[pathlib.Path, str]]] = None,
         **kwargs,
 ):
     """
@@ -64,6 +64,9 @@ def install_update(
     )
 
 
+# Note that robocopy itself also has an option to create a log file,
+# viz. `/log:<filename>`, as well as a `/tee` option, but we want to log *all*
+# output from the batch file, not just output from the robocopy command.
 WIN_LOG_LINES = """
 call :log > "{log_file_path}" 2>&1
 :log
@@ -72,6 +75,7 @@ WIN_ROBOCOPY_OVERWRITE = (
     '/e',  # include subdirectories, even if empty
     '/move',  # deletes files and dirs from source dir after they've been copied
     '/v',  # verbose (show what is going on)
+    '/w:2',  # set retry-timeout (default is 30 seconds)
 )
 WIN_ROBOCOPY_PURGE = '/purge'  # delete all files and dirs in destination folder
 WIN_ROBOCOPY_EXCLUDE_FROM_PURGE = '/xf'  # exclude specified paths from purge
@@ -80,8 +84,6 @@ WIN_ROBOCOPY_EXCLUDE_FROM_PURGE = '/xf'  # exclude specified paths from purge
 WIN_MOVE_FILES_BAT = """@echo off
 {log_lines}
 echo Moving app files...
-rem wait a few seconds for caller to relinquish locks etc. 
-timeout /t 2
 robocopy "{src}" "{dst}" {options}
 echo Done.
 rem Delete self
@@ -116,8 +118,8 @@ def _install_update_win(
         purge_dst_dir: bool,
         exclude_from_purge: List[Union[pathlib.Path, str]],
         as_admin: bool = False,
-        log_file_name: str = None,
-        robocopy_options_override: List[str] = None,
+        log_file_name: Optional[str] = None,
+        robocopy_options_override: Optional[List[str]] = None,
 ):
     """
     Create a batch script that moves files from src to dst, then run the
